AllocError

Struct AllocError 

pub struct AllocError;
🔬This is a nightly-only experimental API. (allocator_api #32838)
The AllocError error indicates an allocation failure that may be due to resource exhaustion or to something wrong when combining the given input arguments with this allocator.